"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.fileFactory = fileFactory;

var _defineProperty2 = _interopRequireDefault(require("@babel/runtime/helpers/defineProperty"));

var _webinyEntity = require("webiny-entity");

function fileFactory(context) {
  var _class, _temp;

  return _temp = _class = class File extends _webinyEntity.Entity {
    constructor() {
      super();
      (0, _defineProperty2.default)(this, "createdBy", void 0);
      (0, _defineProperty2.default)(this, "src", void 0);
      (0, _defineProperty2.default)(this, "description", void 0);
      (0, _defineProperty2.default)(this, "name", void 0);
      (0, _defineProperty2.default)(this, "type", void 0);
      (0, _defineProperty2.default)(this, "tags", void 0);
      const {
        user = {},
        security,
        files
      } = context;
      const {
        User
      } = security.entities;
      this.attr("createdBy").entity(User).setSkipOnPopulate();
      this.attr("size").integer().setValidators("required");
      this.attr("type").char().setValidators("required,maxLength:50");
      this.attr("src").char().setValidators("required,maxLength:200");
      this.attr("name").char().setValidators("required,maxLength:100");
      this.attr("tags").array().onSet(value => {
        if (Array.isArray(value)) {
          return value.map(item => item.toLowerCase());
        }

        return value;
      }).setValidators(tags => {
        if (Array.isArray(tags)) {
          if (tags.length > 15) {
            throw Error("You cannot set more than 15 tags.");
          }

          for (let i = 0; i < tags.length; i++) {
            let tag = tags[i];

            if (typeof tag !== "string") {
              throw Error("Tag must be typeof string.");
            }

            if (tag.length > 50) {
              throw Error(`Tag ${tag} is more than 50 characters long.`);
            }
          }
        }
      });
      this.on("beforeCreate", async () => {
        if (!this.src.startsWith("/") || this.src.startsWith("http")) {
          throw Error(`File "src" must be a relative path, starting with forward slash ("/").`);
        }

        if (await files.entities.File.findOne({
          query: {
            src: this.src
          }
        })) {
          throw Error(`File "src" must be unique. `);
        }

        this.createdBy = user.id;
      });
    }

  }, (0, _defineProperty2.default)(_class, "classId", "File"), _temp;
}
//# sourceMappingURL=File.entity.js.map